# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.ai_inferencing_service_profile import AIInferencingServiceProfile  # noqa: F401,E501


class ServiceDomainProfile(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ai_inferencing_service': 'AIInferencingServiceProfile',
        'enable_ssh': 'bool',
        'ingress_type': 'str',
        'privileged': 'bool'
    }

    attribute_map = {
        'ai_inferencing_service': 'AIInferencingService',
        'enable_ssh': 'enableSSH',
        'ingress_type': 'ingressType',
        'privileged': 'privileged'
    }

    def __init__(self, ai_inferencing_service=None, enable_ssh=None, ingress_type=None, privileged=None):  # noqa: E501
        """ServiceDomainProfile - a model defined in Swagger"""  # noqa: E501
        self._ai_inferencing_service = None
        self._enable_ssh = None
        self._ingress_type = None
        self._privileged = None
        self.discriminator = None
        if ai_inferencing_service is not None:
            self.ai_inferencing_service = ai_inferencing_service
        if enable_ssh is not None:
            self.enable_ssh = enable_ssh
        if ingress_type is not None:
            self.ingress_type = ingress_type
        if privileged is not None:
            self.privileged = privileged

    @property
    def ai_inferencing_service(self):
        """Gets the ai_inferencing_service of this ServiceDomainProfile.  # noqa: E501


        :return: The ai_inferencing_service of this ServiceDomainProfile.  # noqa: E501
        :rtype: AIInferencingServiceProfile
        """
        return self._ai_inferencing_service

    @ai_inferencing_service.setter
    def ai_inferencing_service(self, ai_inferencing_service):
        """Sets the ai_inferencing_service of this ServiceDomainProfile.


        :param ai_inferencing_service: The ai_inferencing_service of this ServiceDomainProfile.  # noqa: E501
        :type: AIInferencingServiceProfile
        """

        self._ai_inferencing_service = ai_inferencing_service

    @property
    def enable_ssh(self):
        """Gets the enable_ssh of this ServiceDomainProfile.  # noqa: E501


        :return: The enable_ssh of this ServiceDomainProfile.  # noqa: E501
        :rtype: bool
        """
        return self._enable_ssh

    @enable_ssh.setter
    def enable_ssh(self, enable_ssh):
        """Sets the enable_ssh of this ServiceDomainProfile.


        :param enable_ssh: The enable_ssh of this ServiceDomainProfile.  # noqa: E501
        :type: bool
        """

        self._enable_ssh = enable_ssh

    @property
    def ingress_type(self):
        """Gets the ingress_type of this ServiceDomainProfile.  # noqa: E501


        :return: The ingress_type of this ServiceDomainProfile.  # noqa: E501
        :rtype: str
        """
        return self._ingress_type

    @ingress_type.setter
    def ingress_type(self, ingress_type):
        """Sets the ingress_type of this ServiceDomainProfile.


        :param ingress_type: The ingress_type of this ServiceDomainProfile.  # noqa: E501
        :type: str
        """
        allowed_values = ["Traefik", "NGINX"]  # noqa: E501
        if ingress_type not in allowed_values:
            raise ValueError(
                "Invalid value for `ingress_type` ({0}), must be one of {1}"  # noqa: E501
                .format(ingress_type, allowed_values)
            )

        self._ingress_type = ingress_type

    @property
    def privileged(self):
        """Gets the privileged of this ServiceDomainProfile.  # noqa: E501


        :return: The privileged of this ServiceDomainProfile.  # noqa: E501
        :rtype: bool
        """
        return self._privileged

    @privileged.setter
    def privileged(self, privileged):
        """Sets the privileged of this ServiceDomainProfile.


        :param privileged: The privileged of this ServiceDomainProfile.  # noqa: E501
        :type: bool
        """

        self._privileged = privileged

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ServiceDomainProfile, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServiceDomainProfile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
