# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.ml_model_api import MLModelApi  # noqa: E501
from kps_api.rest import ApiException


class TestMLModelApi(unittest.TestCase):
    """MLModelApi unit test stubs"""

    def setUp(self):
        self.api = api.ml_model_api.MLModelApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_m_l_model_create(self):
        """Test case for m_l_model_create

        Create a machine learning model.  # noqa: E501
        """
        pass

    def test_m_l_model_delete(self):
        """Test case for m_l_model_delete

        Delete a machine learning model  by its ID.  # noqa: E501
        """
        pass

    def test_m_l_model_get(self):
        """Test case for m_l_model_get

        Get machine learning model by its ID.  # noqa: E501
        """
        pass

    def test_m_l_model_list(self):
        """Test case for m_l_model_list

        Lists machine learning models.  # noqa: E501
        """
        pass

    def test_m_l_model_update(self):
        """Test case for m_l_model_update

        Update a machine learning model by its ID.  # noqa: E501
        """
        pass

    def test_m_l_model_version_create(self):
        """Test case for m_l_model_version_create

        Create a new version of the machine learning model by its ID.  # noqa: E501
        """
        pass

    def test_m_l_model_version_delete(self):
        """Test case for m_l_model_version_delete

        Delete the version of the machine learning model by its ID.  # noqa: E501
        """
        pass

    def test_m_l_model_version_update(self):
        """Test case for m_l_model_version_update

        Update the version of the machine learning model by its ID.  # noqa: E501
        """
        pass

    def test_m_l_model_version_url_get(self):
        """Test case for m_l_model_version_url_get

        Get a pre-signed URL for the machine learning model according to its ID and version.  # noqa: E501
        """
        pass

    def test_project_get_ml_models(self):
        """Test case for project_get_ml_models

        Lists project machine learning models by project ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
