# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.log_api import LogApi  # noqa: E501
from kps_api.rest import ApiException


class TestLogApi(unittest.TestCase):
    """LogApi unit test stubs"""

    def setUp(self):
        self.api = api.log_api.LogApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_application_log_entries_get_v2(self):
        """Test case for application_log_entries_get_v2

        Lists applications log entries specific to an application.  # noqa: E501
        """
        pass

    def test_application_log_entries_list_v2(self):
        """Test case for application_log_entries_list_v2

        Lists application log entries.  # noqa: E501
        """
        pass

    def test_edge_log_entries_get_v2(self):
        """Test case for edge_log_entries_get_v2

        Lists infrastructure log entries for an edge.  # noqa: E501
        """
        pass

    def test_edge_log_entries_list_v2(self):
        """Test case for edge_log_entries_list_v2

        Lists infrastructure log entries for edges.  # noqa: E501
        """
        pass

    def test_log_entries_list_v2(self):
        """Test case for log_entries_list_v2

        Lists log entries.  # noqa: E501
        """
        pass

    def test_log_entry_delete_v2(self):
        """Test case for log_entry_delete_v2

        Delete log entry by ID.  # noqa: E501
        """
        pass

    def test_log_request_download_v2(self):
        """Test case for log_request_download_v2

        Request log download.  # noqa: E501
        """
        pass

    def test_log_request_upload_v2(self):
        """Test case for log_request_upload_v2

        Request log upload.  # noqa: E501
        """
        pass

    def test_log_stream_endpoints(self):
        """Test case for log_stream_endpoints

        Get the endpoints to stream logs for a given container from an edge.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
