# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class HelmAppMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'crds': 'str',
        'metadata': 'str',
        'values': 'str'
    }

    attribute_map = {
        'crds': 'crds',
        'metadata': 'metadata',
        'values': 'values'
    }

    def __init__(self, crds=None, metadata=None, values=None):  # noqa: E501
        """HelmAppMetadata - a model defined in Swagger"""  # noqa: E501
        self._crds = None
        self._metadata = None
        self._values = None
        self.discriminator = None
        if crds is not None:
            self.crds = crds
        self.metadata = metadata
        if values is not None:
            self.values = values

    @property
    def crds(self):
        """Gets the crds of this HelmAppMetadata.  # noqa: E501

        Helm chart CRDs as a string  # noqa: E501

        :return: The crds of this HelmAppMetadata.  # noqa: E501
        :rtype: str
        """
        return self._crds

    @crds.setter
    def crds(self, crds):
        """Sets the crds of this HelmAppMetadata.

        Helm chart CRDs as a string  # noqa: E501

        :param crds: The crds of this HelmAppMetadata.  # noqa: E501
        :type: str
        """

        self._crds = crds

    @property
    def metadata(self):
        """Gets the metadata of this HelmAppMetadata.  # noqa: E501


        :return: The metadata of this HelmAppMetadata.  # noqa: E501
        :rtype: str
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this HelmAppMetadata.


        :param metadata: The metadata of this HelmAppMetadata.  # noqa: E501
        :type: str
        """
        if metadata is None:
            raise ValueError("Invalid value for `metadata`, must not be `None`")  # noqa: E501

        self._metadata = metadata

    @property
    def values(self):
        """Gets the values of this HelmAppMetadata.  # noqa: E501

        values.yaml as a string  # noqa: E501

        :return: The values of this HelmAppMetadata.  # noqa: E501
        :rtype: str
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this HelmAppMetadata.

        values.yaml as a string  # noqa: E501

        :param values: The values of this HelmAppMetadata.  # noqa: E501
        :type: str
        """

        self._values = values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HelmAppMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HelmAppMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
