# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.service_binding_resource import ServiceBindingResource  # noqa: F401,E501


class ServiceBindingParam(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bind_resource': 'ServiceBindingResource',
        'description': 'str',
        'id': 'str',
        'name': 'str',
        'parameters': 'dict(str, object)',
        'svc_class_id': 'str'
    }

    attribute_map = {
        'bind_resource': 'bindResource',
        'description': 'description',
        'id': 'id',
        'name': 'name',
        'parameters': 'parameters',
        'svc_class_id': 'svcClassId'
    }

    def __init__(self, bind_resource=None, description=None, id=None, name=None, parameters=None, svc_class_id=None):  # noqa: E501
        """ServiceBindingParam - a model defined in Swagger"""  # noqa: E501
        self._bind_resource = None
        self._description = None
        self._id = None
        self._name = None
        self._parameters = None
        self._svc_class_id = None
        self.discriminator = None
        if bind_resource is not None:
            self.bind_resource = bind_resource
        if description is not None:
            self.description = description
        if id is not None:
            self.id = id
        self.name = name
        if parameters is not None:
            self.parameters = parameters
        self.svc_class_id = svc_class_id

    @property
    def bind_resource(self):
        """Gets the bind_resource of this ServiceBindingParam.  # noqa: E501


        :return: The bind_resource of this ServiceBindingParam.  # noqa: E501
        :rtype: ServiceBindingResource
        """
        return self._bind_resource

    @bind_resource.setter
    def bind_resource(self, bind_resource):
        """Sets the bind_resource of this ServiceBindingParam.


        :param bind_resource: The bind_resource of this ServiceBindingParam.  # noqa: E501
        :type: ServiceBindingResource
        """

        self._bind_resource = bind_resource

    @property
    def description(self):
        """Gets the description of this ServiceBindingParam.  # noqa: E501


        :return: The description of this ServiceBindingParam.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ServiceBindingParam.


        :param description: The description of this ServiceBindingParam.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """Gets the id of this ServiceBindingParam.  # noqa: E501


        :return: The id of this ServiceBindingParam.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ServiceBindingParam.


        :param id: The id of this ServiceBindingParam.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this ServiceBindingParam.  # noqa: E501


        :return: The name of this ServiceBindingParam.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ServiceBindingParam.


        :param name: The name of this ServiceBindingParam.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def parameters(self):
        """Gets the parameters of this ServiceBindingParam.  # noqa: E501


        :return: The parameters of this ServiceBindingParam.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this ServiceBindingParam.


        :param parameters: The parameters of this ServiceBindingParam.  # noqa: E501
        :type: dict(str, object)
        """

        self._parameters = parameters

    @property
    def svc_class_id(self):
        """Gets the svc_class_id of this ServiceBindingParam.  # noqa: E501


        :return: The svc_class_id of this ServiceBindingParam.  # noqa: E501
        :rtype: str
        """
        return self._svc_class_id

    @svc_class_id.setter
    def svc_class_id(self, svc_class_id):
        """Sets the svc_class_id of this ServiceBindingParam.


        :param svc_class_id: The svc_class_id of this ServiceBindingParam.  # noqa: E501
        :type: str
        """
        if svc_class_id is None:
            raise ValueError("Invalid value for `svc_class_id`, must not be `None`")  # noqa: E501

        self._svc_class_id = svc_class_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ServiceBindingParam, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServiceBindingParam):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
