# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.user_api_token_api import UserAPITokenApi  # noqa: E501
from kps_api.rest import ApiException


class TestUserAPITokenApi(unittest.TestCase):
    """UserAPITokenApi unit test stubs"""

    def setUp(self):
        self.api = api.user_api_token_api.UserAPITokenApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_user_api_token_create(self):
        """Test case for user_api_token_create

        Create a user API token.  # noqa: E501
        """
        pass

    def test_user_api_token_delete(self):
        """Test case for user_api_token_delete

        Delete current user API token.  # noqa: E501
        """
        pass

    def test_user_api_token_get(self):
        """Test case for user_api_token_get

        Get current user API tokens.  # noqa: E501
        """
        pass

    def test_user_api_token_list(self):
        """Test case for user_api_token_list

        Get all user API tokens.  # noqa: E501
        """
        pass

    def test_user_api_token_update(self):
        """Test case for user_api_token_update

        Update user API token.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
