# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.response_flags import ResponseFlags  # noqa: F401,E501
from kps_api.models.response_hosts import ResponseHosts  # noqa: F401,E501


class ResponseDetail(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'flags': 'ResponseFlags',
        'hosts': 'ResponseHosts'
    }

    attribute_map = {
        'flags': 'flags',
        'hosts': 'hosts'
    }

    def __init__(self, flags=None, hosts=None):  # noqa: E501
        """ResponseDetail - a model defined in Swagger"""  # noqa: E501
        self._flags = None
        self._hosts = None
        self.discriminator = None
        if flags is not None:
            self.flags = flags
        if hosts is not None:
            self.hosts = hosts

    @property
    def flags(self):
        """Gets the flags of this ResponseDetail.  # noqa: E501


        :return: The flags of this ResponseDetail.  # noqa: E501
        :rtype: ResponseFlags
        """
        return self._flags

    @flags.setter
    def flags(self, flags):
        """Sets the flags of this ResponseDetail.


        :param flags: The flags of this ResponseDetail.  # noqa: E501
        :type: ResponseFlags
        """

        self._flags = flags

    @property
    def hosts(self):
        """Gets the hosts of this ResponseDetail.  # noqa: E501


        :return: The hosts of this ResponseDetail.  # noqa: E501
        :rtype: ResponseHosts
        """
        return self._hosts

    @hosts.setter
    def hosts(self, hosts):
        """Sets the hosts of this ResponseDetail.


        :param hosts: The hosts of this ResponseDetail.  # noqa: E501
        :type: ResponseHosts
        """

        self._hosts = hosts

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResponseDetail, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseDetail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
