# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.runtime_environment_api import RuntimeEnvironmentApi  # noqa: E501
from kps_api.rest import ApiException


class TestRuntimeEnvironmentApi(unittest.TestCase):
    """RuntimeEnvironmentApi unit test stubs"""

    def setUp(self):
        self.api = api.runtime_environment_api.RuntimeEnvironmentApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_project_get_runtime_environments(self):
        """Test case for project_get_runtime_environments

        Gets runtime environments for a project by project ID.  # noqa: E501
        """
        pass

    def test_runtime_environment_create(self):
        """Test case for runtime_environment_create

        Create a runtime environment for functions.  # noqa: E501
        """
        pass

    def test_runtime_environment_delete(self):
        """Test case for runtime_environment_delete

        Delete a runtime environment by its ID.  # noqa: E501
        """
        pass

    def test_runtime_environment_get(self):
        """Test case for runtime_environment_get

        Get a runtime environment by its ID.  # noqa: E501
        """
        pass

    def test_runtime_environment_list(self):
        """Test case for runtime_environment_list

        Get runtime environments.  # noqa: E501
        """
        pass

    def test_runtime_environment_update(self):
        """Test case for runtime_environment_update

        Update the runtime environment by its ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
