# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Iter8Metric(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'absent_value': 'str',
        'is_counter': 'bool',
        'query_template': 'str',
        'sample_size_template': 'str'
    }

    attribute_map = {
        'absent_value': 'absent_value',
        'is_counter': 'is_counter',
        'query_template': 'query_template',
        'sample_size_template': 'sample_size_template'
    }

    def __init__(self, absent_value=None, is_counter=None, query_template=None, sample_size_template=None):  # noqa: E501
        """Iter8Metric - a model defined in Swagger"""  # noqa: E501
        self._absent_value = None
        self._is_counter = None
        self._query_template = None
        self._sample_size_template = None
        self.discriminator = None
        if absent_value is not None:
            self.absent_value = absent_value
        if is_counter is not None:
            self.is_counter = is_counter
        if query_template is not None:
            self.query_template = query_template
        if sample_size_template is not None:
            self.sample_size_template = sample_size_template

    @property
    def absent_value(self):
        """Gets the absent_value of this Iter8Metric.  # noqa: E501


        :return: The absent_value of this Iter8Metric.  # noqa: E501
        :rtype: str
        """
        return self._absent_value

    @absent_value.setter
    def absent_value(self, absent_value):
        """Sets the absent_value of this Iter8Metric.


        :param absent_value: The absent_value of this Iter8Metric.  # noqa: E501
        :type: str
        """

        self._absent_value = absent_value

    @property
    def is_counter(self):
        """Gets the is_counter of this Iter8Metric.  # noqa: E501


        :return: The is_counter of this Iter8Metric.  # noqa: E501
        :rtype: bool
        """
        return self._is_counter

    @is_counter.setter
    def is_counter(self, is_counter):
        """Sets the is_counter of this Iter8Metric.


        :param is_counter: The is_counter of this Iter8Metric.  # noqa: E501
        :type: bool
        """

        self._is_counter = is_counter

    @property
    def query_template(self):
        """Gets the query_template of this Iter8Metric.  # noqa: E501


        :return: The query_template of this Iter8Metric.  # noqa: E501
        :rtype: str
        """
        return self._query_template

    @query_template.setter
    def query_template(self, query_template):
        """Sets the query_template of this Iter8Metric.


        :param query_template: The query_template of this Iter8Metric.  # noqa: E501
        :type: str
        """

        self._query_template = query_template

    @property
    def sample_size_template(self):
        """Gets the sample_size_template of this Iter8Metric.  # noqa: E501


        :return: The sample_size_template of this Iter8Metric.  # noqa: E501
        :rtype: str
        """
        return self._sample_size_template

    @sample_size_template.setter
    def sample_size_template(self, sample_size_template):
        """Sets the sample_size_template of this Iter8Metric.


        :param sample_size_template: The sample_size_template of this Iter8Metric.  # noqa: E501
        :type: str
        """

        self._sample_size_template = sample_size_template

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Iter8Metric, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Iter8Metric):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
