# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class EdgeCert(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ca_certificate': 'str',
        'certificate': 'str',
        'client_certificate': 'str',
        'client_private_key': 'str',
        'edge_certificate': 'str',
        'edge_id': 'str',
        'edge_private_key': 'str',
        'id': 'str',
        'locked': 'bool',
        'private_key': 'str'
    }

    attribute_map = {
        'ca_certificate': 'CACertificate',
        'certificate': 'certificate',
        'client_certificate': 'clientCertificate',
        'client_private_key': 'clientPrivateKey',
        'edge_certificate': 'edgeCertificate',
        'edge_id': 'edgeId',
        'edge_private_key': 'edgePrivateKey',
        'id': 'id',
        'locked': 'locked',
        'private_key': 'privateKey'
    }

    def __init__(self, ca_certificate=None, certificate=None, client_certificate=None, client_private_key=None, edge_certificate=None, edge_id=None, edge_private_key=None, id=None, locked=None, private_key=None):  # noqa: E501
        """EdgeCert - a model defined in Swagger"""  # noqa: E501
        self._ca_certificate = None
        self._certificate = None
        self._client_certificate = None
        self._client_private_key = None
        self._edge_certificate = None
        self._edge_id = None
        self._edge_private_key = None
        self._id = None
        self._locked = None
        self._private_key = None
        self.discriminator = None
        self.ca_certificate = ca_certificate
        self.certificate = certificate
        self.client_certificate = client_certificate
        self.client_private_key = client_private_key
        self.edge_certificate = edge_certificate
        self.edge_id = edge_id
        self.edge_private_key = edge_private_key
        if id is not None:
            self.id = id
        if locked is not None:
            self.locked = locked
        self.private_key = private_key

    @property
    def ca_certificate(self):
        """Gets the ca_certificate of this EdgeCert.  # noqa: E501

        Root CA certificate for the tenant.  # noqa: E501

        :return: The ca_certificate of this EdgeCert.  # noqa: E501
        :rtype: str
        """
        return self._ca_certificate

    @ca_certificate.setter
    def ca_certificate(self, ca_certificate):
        """Sets the ca_certificate of this EdgeCert.

        Root CA certificate for the tenant.  # noqa: E501

        :param ca_certificate: The ca_certificate of this EdgeCert.  # noqa: E501
        :type: str
        """
        if ca_certificate is None:
            raise ValueError("Invalid value for `ca_certificate`, must not be `None`")  # noqa: E501

        self._ca_certificate = ca_certificate

    @property
    def certificate(self):
        """Gets the certificate of this EdgeCert.  # noqa: E501

        Certificate for the edge using old/fixed root CA.  # noqa: E501

        :return: The certificate of this EdgeCert.  # noqa: E501
        :rtype: str
        """
        return self._certificate

    @certificate.setter
    def certificate(self, certificate):
        """Sets the certificate of this EdgeCert.

        Certificate for the edge using old/fixed root CA.  # noqa: E501

        :param certificate: The certificate of this EdgeCert.  # noqa: E501
        :type: str
        """
        if certificate is None:
            raise ValueError("Invalid value for `certificate`, must not be `None`")  # noqa: E501

        self._certificate = certificate

    @property
    def client_certificate(self):
        """Gets the client_certificate of this EdgeCert.  # noqa: E501

        Certificate for mqtt client on the edge  # noqa: E501

        :return: The client_certificate of this EdgeCert.  # noqa: E501
        :rtype: str
        """
        return self._client_certificate

    @client_certificate.setter
    def client_certificate(self, client_certificate):
        """Sets the client_certificate of this EdgeCert.

        Certificate for mqtt client on the edge  # noqa: E501

        :param client_certificate: The client_certificate of this EdgeCert.  # noqa: E501
        :type: str
        """
        if client_certificate is None:
            raise ValueError("Invalid value for `client_certificate`, must not be `None`")  # noqa: E501

        self._client_certificate = client_certificate

    @property
    def client_private_key(self):
        """Gets the client_private_key of this EdgeCert.  # noqa: E501

        Encrypted private key corresponding to the client certificate.  # noqa: E501

        :return: The client_private_key of this EdgeCert.  # noqa: E501
        :rtype: str
        """
        return self._client_private_key

    @client_private_key.setter
    def client_private_key(self, client_private_key):
        """Sets the client_private_key of this EdgeCert.

        Encrypted private key corresponding to the client certificate.  # noqa: E501

        :param client_private_key: The client_private_key of this EdgeCert.  # noqa: E501
        :type: str
        """
        if client_private_key is None:
            raise ValueError("Invalid value for `client_private_key`, must not be `None`")  # noqa: E501

        self._client_private_key = client_private_key

    @property
    def edge_certificate(self):
        """Gets the edge_certificate of this EdgeCert.  # noqa: E501

        Certificate for the edge using per-tenant root CA.  # noqa: E501

        :return: The edge_certificate of this EdgeCert.  # noqa: E501
        :rtype: str
        """
        return self._edge_certificate

    @edge_certificate.setter
    def edge_certificate(self, edge_certificate):
        """Sets the edge_certificate of this EdgeCert.

        Certificate for the edge using per-tenant root CA.  # noqa: E501

        :param edge_certificate: The edge_certificate of this EdgeCert.  # noqa: E501
        :type: str
        """
        if edge_certificate is None:
            raise ValueError("Invalid value for `edge_certificate`, must not be `None`")  # noqa: E501

        self._edge_certificate = edge_certificate

    @property
    def edge_id(self):
        """Gets the edge_id of this EdgeCert.  # noqa: E501

        ID of the edge this entity belongs to  # noqa: E501

        :return: The edge_id of this EdgeCert.  # noqa: E501
        :rtype: str
        """
        return self._edge_id

    @edge_id.setter
    def edge_id(self, edge_id):
        """Sets the edge_id of this EdgeCert.

        ID of the edge this entity belongs to  # noqa: E501

        :param edge_id: The edge_id of this EdgeCert.  # noqa: E501
        :type: str
        """
        if edge_id is None:
            raise ValueError("Invalid value for `edge_id`, must not be `None`")  # noqa: E501

        self._edge_id = edge_id

    @property
    def edge_private_key(self):
        """Gets the edge_private_key of this EdgeCert.  # noqa: E501

        Encrypted private key using per-tenant root CA.  # noqa: E501

        :return: The edge_private_key of this EdgeCert.  # noqa: E501
        :rtype: str
        """
        return self._edge_private_key

    @edge_private_key.setter
    def edge_private_key(self, edge_private_key):
        """Sets the edge_private_key of this EdgeCert.

        Encrypted private key using per-tenant root CA.  # noqa: E501

        :param edge_private_key: The edge_private_key of this EdgeCert.  # noqa: E501
        :type: str
        """
        if edge_private_key is None:
            raise ValueError("Invalid value for `edge_private_key`, must not be `None`")  # noqa: E501

        self._edge_private_key = edge_private_key

    @property
    def id(self):
        """Gets the id of this EdgeCert.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this EdgeCert.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EdgeCert.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this EdgeCert.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def locked(self):
        """Gets the locked of this EdgeCert.  # noqa: E501


        :return: The locked of this EdgeCert.  # noqa: E501
        :rtype: bool
        """
        return self._locked

    @locked.setter
    def locked(self, locked):
        """Sets the locked of this EdgeCert.


        :param locked: The locked of this EdgeCert.  # noqa: E501
        :type: bool
        """

        self._locked = locked

    @property
    def private_key(self):
        """Gets the private_key of this EdgeCert.  # noqa: E501

        Encrypted private key using old/fixed root CA.  # noqa: E501

        :return: The private_key of this EdgeCert.  # noqa: E501
        :rtype: str
        """
        return self._private_key

    @private_key.setter
    def private_key(self, private_key):
        """Sets the private_key of this EdgeCert.

        Encrypted private key using old/fixed root CA.  # noqa: E501

        :param private_key: The private_key of this EdgeCert.  # noqa: E501
        :type: str
        """
        if private_key is None:
            raise ValueError("Invalid value for `private_key`, must not be `None`")  # noqa: E501

        self._private_key = private_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EdgeCert, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EdgeCert):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
