# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from models.function import Function  # noqa: E501
from kps_api.rest import ApiException


class TestFunction(unittest.TestCase):
    """Function unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testFunction(self):
        """Test Function"""
        # FIXME: construct object with mandatory attributes with example values
        # model = kps_api.models.function.Function()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
