# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.connector_class_api import ConnectorClassApi  # noqa: E501
from kps_api.rest import ApiException


class TestConnectorClassApi(unittest.TestCase):
    """ConnectorClassApi unit test stubs"""

    def setUp(self):
        self.api = api.connector_class_api.ConnectorClassApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_connector_class_create(self):
        """Test case for connector_class_create

        Create a connector class.  # noqa: E501
        """
        pass

    def test_connector_class_delete(self):
        """Test case for connector_class_delete

        Delete a specific connector class.  # noqa: E501
        """
        pass

    def test_connector_class_get(self):
        """Test case for connector_class_get

        Get a connector class by ID.  # noqa: E501
        """
        pass

    def test_connector_class_list(self):
        """Test case for connector_class_list

        Get all connector class.  # noqa: E501
        """
        pass

    def test_connector_class_update(self):
        """Test case for connector_class_update

        Update a connector class.  # noqa: E501
        """
        pass

    def test_connector_instances_by_class_id_list(self):
        """Test case for connector_instances_by_class_id_list

        Get all connector instances by class id.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
