# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class RuntimeEnvironment(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'docker_profile_id': 'str',
        'docker_repo_uri': 'str',
        'dockerfile': 'str',
        'id': 'str',
        'language': 'str',
        'name': 'str',
        'project_id': 'str'
    }

    attribute_map = {
        'description': 'description',
        'docker_profile_id': 'dockerProfileID',
        'docker_repo_uri': 'dockerRepoURI',
        'dockerfile': 'dockerfile',
        'id': 'id',
        'language': 'language',
        'name': 'name',
        'project_id': 'projectId'
    }

    def __init__(self, description=None, docker_profile_id=None, docker_repo_uri=None, dockerfile=None, id=None, language=None, name=None, project_id=None):  # noqa: E501
        """RuntimeEnvironment - a model defined in Swagger"""  # noqa: E501
        self._description = None
        self._docker_profile_id = None
        self._docker_repo_uri = None
        self._dockerfile = None
        self._id = None
        self._language = None
        self._name = None
        self._project_id = None
        self.discriminator = None
        if description is not None:
            self.description = description
        if docker_profile_id is not None:
            self.docker_profile_id = docker_profile_id
        if docker_repo_uri is not None:
            self.docker_repo_uri = docker_repo_uri
        if dockerfile is not None:
            self.dockerfile = dockerfile
        if id is not None:
            self.id = id
        self.language = language
        self.name = name
        if project_id is not None:
            self.project_id = project_id

    @property
    def description(self):
        """Gets the description of this RuntimeEnvironment.  # noqa: E501

        Runtime description.  # noqa: E501

        :return: The description of this RuntimeEnvironment.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this RuntimeEnvironment.

        Runtime description.  # noqa: E501

        :param description: The description of this RuntimeEnvironment.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def docker_profile_id(self):
        """Gets the docker_profile_id of this RuntimeEnvironment.  # noqa: E501

        DockerProfile ID (Container registry profile) used by this script runtime.  # noqa: E501

        :return: The docker_profile_id of this RuntimeEnvironment.  # noqa: E501
        :rtype: str
        """
        return self._docker_profile_id

    @docker_profile_id.setter
    def docker_profile_id(self, docker_profile_id):
        """Sets the docker_profile_id of this RuntimeEnvironment.

        DockerProfile ID (Container registry profile) used by this script runtime.  # noqa: E501

        :param docker_profile_id: The docker_profile_id of this RuntimeEnvironment.  # noqa: E501
        :type: str
        """

        self._docker_profile_id = docker_profile_id

    @property
    def docker_repo_uri(self):
        """Gets the docker_repo_uri of this RuntimeEnvironment.  # noqa: E501

        Docker repository URI of the script runtime.  # noqa: E501

        :return: The docker_repo_uri of this RuntimeEnvironment.  # noqa: E501
        :rtype: str
        """
        return self._docker_repo_uri

    @docker_repo_uri.setter
    def docker_repo_uri(self, docker_repo_uri):
        """Sets the docker_repo_uri of this RuntimeEnvironment.

        Docker repository URI of the script runtime.  # noqa: E501

        :param docker_repo_uri: The docker_repo_uri of this RuntimeEnvironment.  # noqa: E501
        :type: str
        """

        self._docker_repo_uri = docker_repo_uri

    @property
    def dockerfile(self):
        """Gets the dockerfile of this RuntimeEnvironment.  # noqa: E501

        Dockerfile for the script runtime. Serves as documentation for the script runtime.  # noqa: E501

        :return: The dockerfile of this RuntimeEnvironment.  # noqa: E501
        :rtype: str
        """
        return self._dockerfile

    @dockerfile.setter
    def dockerfile(self, dockerfile):
        """Sets the dockerfile of this RuntimeEnvironment.

        Dockerfile for the script runtime. Serves as documentation for the script runtime.  # noqa: E501

        :param dockerfile: The dockerfile of this RuntimeEnvironment.  # noqa: E501
        :type: str
        """

        self._dockerfile = dockerfile

    @property
    def id(self):
        """Gets the id of this RuntimeEnvironment.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this RuntimeEnvironment.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RuntimeEnvironment.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this RuntimeEnvironment.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def language(self):
        """Gets the language of this RuntimeEnvironment.  # noqa: E501

        Runtime enviroment script language.  # noqa: E501

        :return: The language of this RuntimeEnvironment.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this RuntimeEnvironment.

        Runtime enviroment script language.  # noqa: E501

        :param language: The language of this RuntimeEnvironment.  # noqa: E501
        :type: str
        """
        if language is None:
            raise ValueError("Invalid value for `language`, must not be `None`")  # noqa: E501

        self._language = language

    @property
    def name(self):
        """Gets the name of this RuntimeEnvironment.  # noqa: E501

        Name of the runtime environment.  # noqa: E501

        :return: The name of this RuntimeEnvironment.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RuntimeEnvironment.

        Name of the runtime environment.  # noqa: E501

        :param name: The name of this RuntimeEnvironment.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def project_id(self):
        """Gets the project_id of this RuntimeEnvironment.  # noqa: E501

        ID of parent project, required for custom (non-built-in) script runtimes.  # noqa: E501

        :return: The project_id of this RuntimeEnvironment.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this RuntimeEnvironment.

        ID of parent project, required for custom (non-built-in) script runtimes.  # noqa: E501

        :param project_id: The project_id of this RuntimeEnvironment.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuntimeEnvironment, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuntimeEnvironment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
