# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.data_source_api import DataSourceApi  # noqa: E501
from kps_api.rest import ApiException


class TestDataSourceApi(unittest.TestCase):
    """DataSourceApi unit test stubs"""

    def setUp(self):
        self.api = api.data_source_api.DataSourceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_data_source_create_v2(self):
        """Test case for data_source_create_v2

        Create a data source.  # noqa: E501
        """
        pass

    def test_data_source_delete_v2(self):
        """Test case for data_source_delete_v2

        Delete a specific data source.  # noqa: E501
        """
        pass

    def test_data_source_get_artifact_v2(self):
        """Test case for data_source_get_artifact_v2

        Get data source artifacts according to its ID.  # noqa: E501
        """
        pass

    def test_data_source_get_v2(self):
        """Test case for data_source_get_v2

        Get a data source according to its ID.  # noqa: E501
        """
        pass

    def test_data_source_list_v2(self):
        """Test case for data_source_list_v2

        Get all data sources.  # noqa: E501
        """
        pass

    def test_data_source_update_v3(self):
        """Test case for data_source_update_v3

        Update a data source.  # noqa: E501
        """
        pass

    def test_edge_get_datasources_v2(self):
        """Test case for edge_get_datasources_v2

        Get all data sources associated with an edge.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
