# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CloudProfileProjectUsage(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data_pipeline_ids': 'list[str]',
        'project_id': 'str'
    }

    attribute_map = {
        'data_pipeline_ids': 'dataPipelineIds',
        'project_id': 'projectId'
    }

    def __init__(self, data_pipeline_ids=None, project_id=None):  # noqa: E501
        """CloudProfileProjectUsage - a model defined in Swagger"""  # noqa: E501
        self._data_pipeline_ids = None
        self._project_id = None
        self.discriminator = None
        self.data_pipeline_ids = data_pipeline_ids
        self.project_id = project_id

    @property
    def data_pipeline_ids(self):
        """Gets the data_pipeline_ids of this CloudProfileProjectUsage.  # noqa: E501

        IDs of data pipelines in the project that uses the cloud profile  # noqa: E501

        :return: The data_pipeline_ids of this CloudProfileProjectUsage.  # noqa: E501
        :rtype: list[str]
        """
        return self._data_pipeline_ids

    @data_pipeline_ids.setter
    def data_pipeline_ids(self, data_pipeline_ids):
        """Sets the data_pipeline_ids of this CloudProfileProjectUsage.

        IDs of data pipelines in the project that uses the cloud profile  # noqa: E501

        :param data_pipeline_ids: The data_pipeline_ids of this CloudProfileProjectUsage.  # noqa: E501
        :type: list[str]
        """
        if data_pipeline_ids is None:
            raise ValueError("Invalid value for `data_pipeline_ids`, must not be `None`")  # noqa: E501

        self._data_pipeline_ids = data_pipeline_ids

    @property
    def project_id(self):
        """Gets the project_id of this CloudProfileProjectUsage.  # noqa: E501

        ID of the project  # noqa: E501

        :return: The project_id of this CloudProfileProjectUsage.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this CloudProfileProjectUsage.

        ID of the project  # noqa: E501

        :param project_id: The project_id of this CloudProfileProjectUsage.  # noqa: E501
        :type: str
        """
        if project_id is None:
            raise ValueError("Invalid value for `project_id`, must not be `None`")  # noqa: E501

        self._project_id = project_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CloudProfileProjectUsage, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CloudProfileProjectUsage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
