# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ResourcePermissions(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'create': 'bool',
        'delete': 'bool',
        'update': 'bool'
    }

    attribute_map = {
        'create': 'create',
        'delete': 'delete',
        'update': 'update'
    }

    def __init__(self, create=None, delete=None, update=None):  # noqa: E501
        """ResourcePermissions - a model defined in Swagger"""  # noqa: E501
        self._create = None
        self._delete = None
        self._update = None
        self.discriminator = None
        if create is not None:
            self.create = create
        if delete is not None:
            self.delete = delete
        if update is not None:
            self.update = update

    @property
    def create(self):
        """Gets the create of this ResourcePermissions.  # noqa: E501


        :return: The create of this ResourcePermissions.  # noqa: E501
        :rtype: bool
        """
        return self._create

    @create.setter
    def create(self, create):
        """Sets the create of this ResourcePermissions.


        :param create: The create of this ResourcePermissions.  # noqa: E501
        :type: bool
        """

        self._create = create

    @property
    def delete(self):
        """Gets the delete of this ResourcePermissions.  # noqa: E501


        :return: The delete of this ResourcePermissions.  # noqa: E501
        :rtype: bool
        """
        return self._delete

    @delete.setter
    def delete(self, delete):
        """Sets the delete of this ResourcePermissions.


        :param delete: The delete of this ResourcePermissions.  # noqa: E501
        :type: bool
        """

        self._delete = delete

    @property
    def update(self):
        """Gets the update of this ResourcePermissions.  # noqa: E501


        :return: The update of this ResourcePermissions.  # noqa: E501
        :rtype: bool
        """
        return self._update

    @update.setter
    def update(self, update):
        """Sets the update of this ResourcePermissions.


        :param update: The update of this ResourcePermissions.  # noqa: E501
        :type: bool
        """

        self._update = update

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResourcePermissions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourcePermissions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
