# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.log_collector_api import LogCollectorApi  # noqa: E501
from kps_api.rest import ApiException


class TestLogCollectorApi(unittest.TestCase):
    """LogCollectorApi unit test stubs"""

    def setUp(self):
        self.api = api.log_collector_api.LogCollectorApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_log_collector_create(self):
        """Test case for log_collector_create

        Create a log collector.  # noqa: E501
        """
        pass

    def test_log_collector_delete(self):
        """Test case for log_collector_delete

        Delete a log collector.  # noqa: E501
        """
        pass

    def test_log_collector_get(self):
        """Test case for log_collector_get

        Get information about log collector  # noqa: E501
        """
        pass

    def test_log_collector_start(self):
        """Test case for log_collector_start

        Start a log collector.  # noqa: E501
        """
        pass

    def test_log_collector_stop(self):
        """Test case for log_collector_stop

        Stop a log collector.  # noqa: E501
        """
        pass

    def test_log_collector_update(self):
        """Test case for log_collector_update

        Update a log collector.  # noqa: E501
        """
        pass

    def test_log_collectors_list(self):
        """Test case for log_collectors_list

        Get configured log collectors in a system.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
