# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ClusterRbacConfigSpec(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'exclusion': 'object',
        'inclusion': 'object',
        'mode': 'object'
    }

    attribute_map = {
        'exclusion': 'exclusion',
        'inclusion': 'inclusion',
        'mode': 'mode'
    }

    def __init__(self, exclusion=None, inclusion=None, mode=None):  # noqa: E501
        """ClusterRbacConfigSpec - a model defined in Swagger"""  # noqa: E501
        self._exclusion = None
        self._inclusion = None
        self._mode = None
        self.discriminator = None
        if exclusion is not None:
            self.exclusion = exclusion
        if inclusion is not None:
            self.inclusion = inclusion
        if mode is not None:
            self.mode = mode

    @property
    def exclusion(self):
        """Gets the exclusion of this ClusterRbacConfigSpec.  # noqa: E501


        :return: The exclusion of this ClusterRbacConfigSpec.  # noqa: E501
        :rtype: object
        """
        return self._exclusion

    @exclusion.setter
    def exclusion(self, exclusion):
        """Sets the exclusion of this ClusterRbacConfigSpec.


        :param exclusion: The exclusion of this ClusterRbacConfigSpec.  # noqa: E501
        :type: object
        """

        self._exclusion = exclusion

    @property
    def inclusion(self):
        """Gets the inclusion of this ClusterRbacConfigSpec.  # noqa: E501


        :return: The inclusion of this ClusterRbacConfigSpec.  # noqa: E501
        :rtype: object
        """
        return self._inclusion

    @inclusion.setter
    def inclusion(self, inclusion):
        """Sets the inclusion of this ClusterRbacConfigSpec.


        :param inclusion: The inclusion of this ClusterRbacConfigSpec.  # noqa: E501
        :type: object
        """

        self._inclusion = inclusion

    @property
    def mode(self):
        """Gets the mode of this ClusterRbacConfigSpec.  # noqa: E501


        :return: The mode of this ClusterRbacConfigSpec.  # noqa: E501
        :rtype: object
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this ClusterRbacConfigSpec.


        :param mode: The mode of this ClusterRbacConfigSpec.  # noqa: E501
        :type: object
        """

        self._mode = mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ClusterRbacConfigSpec, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClusterRbacConfigSpec):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
