# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.http_service_proxy_api import HTTPServiceProxyApi  # noqa: E501
from kps_api.rest import ApiException


class TestHTTPServiceProxyApi(unittest.TestCase):
    """HTTPServiceProxyApi unit test stubs"""

    def setUp(self):
        self.api = api.http_service_proxy_api.HTTPServiceProxyApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_h_ttp_service_proxy_create(self):
        """Test case for h_ttp_service_proxy_create

        Create a HTTP service proxy.  # noqa: E501
        """
        pass

    def test_h_ttp_service_proxy_delete(self):
        """Test case for h_ttp_service_proxy_delete

        Delete HTTP service proxy.  # noqa: E501
        """
        pass

    def test_h_ttp_service_proxy_get(self):
        """Test case for h_ttp_service_proxy_get

        Get a HTTP service proxy by its ID.  # noqa: E501
        """
        pass

    def test_h_ttp_service_proxy_list(self):
        """Test case for h_ttp_service_proxy_list

        Get all HTTP service proxies.  # noqa: E501
        """
        pass

    def test_h_ttp_service_proxy_update(self):
        """Test case for h_ttp_service_proxy_update

        Update a HTTP service proxy by its ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
