# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.function_api import FunctionApi  # noqa: E501
from kps_api.rest import ApiException


class TestFunctionApi(unittest.TestCase):
    """FunctionApi unit test stubs"""

    def setUp(self):
        self.api = api.function_api.FunctionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_function_create(self):
        """Test case for function_create

        Create a function.  # noqa: E501
        """
        pass

    def test_function_delete(self):
        """Test case for function_delete

        Delete a function by its ID.  # noqa: E501
        """
        pass

    def test_function_get(self):
        """Test case for function_get

        Get a function by its ID.  # noqa: E501
        """
        pass

    def test_function_list(self):
        """Test case for function_list

        Get functions.  # noqa: E501
        """
        pass

    def test_function_update(self):
        """Test case for function_update

        Update function by its ID  # noqa: E501
        """
        pass

    def test_project_get_functions(self):
        """Test case for project_get_functions

        Get functions by project ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
