# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AppListItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'istio_sidecar': 'bool',
        'labels': 'dict(str, str)',
        'name': 'str'
    }

    attribute_map = {
        'istio_sidecar': 'istioSidecar',
        'labels': 'labels',
        'name': 'name'
    }

    def __init__(self, istio_sidecar=None, labels=None, name=None):  # noqa: E501
        """AppListItem - a model defined in Swagger"""  # noqa: E501
        self._istio_sidecar = None
        self._labels = None
        self._name = None
        self.discriminator = None
        self.istio_sidecar = istio_sidecar
        if labels is not None:
            self.labels = labels
        self.name = name

    @property
    def istio_sidecar(self):
        """Gets the istio_sidecar of this AppListItem.  # noqa: E501

        Define if all Pods related to the Workloads of this app has an IstioSidecar deployed  # noqa: E501

        :return: The istio_sidecar of this AppListItem.  # noqa: E501
        :rtype: bool
        """
        return self._istio_sidecar

    @istio_sidecar.setter
    def istio_sidecar(self, istio_sidecar):
        """Sets the istio_sidecar of this AppListItem.

        Define if all Pods related to the Workloads of this app has an IstioSidecar deployed  # noqa: E501

        :param istio_sidecar: The istio_sidecar of this AppListItem.  # noqa: E501
        :type: bool
        """
        if istio_sidecar is None:
            raise ValueError("Invalid value for `istio_sidecar`, must not be `None`")  # noqa: E501

        self._istio_sidecar = istio_sidecar

    @property
    def labels(self):
        """Gets the labels of this AppListItem.  # noqa: E501

        Labels for App  # noqa: E501

        :return: The labels of this AppListItem.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this AppListItem.

        Labels for App  # noqa: E501

        :param labels: The labels of this AppListItem.  # noqa: E501
        :type: dict(str, str)
        """

        self._labels = labels

    @property
    def name(self):
        """Gets the name of this AppListItem.  # noqa: E501

        Name of the application  # noqa: E501

        :return: The name of this AppListItem.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AppListItem.

        Name of the application  # noqa: E501

        :param name: The name of this AppListItem.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AppListItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AppListItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
