# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.service_domain_api import ServiceDomainApi  # noqa: E501
from kps_api.rest import ApiException


class TestServiceDomainApi(unittest.TestCase):
    """ServiceDomainApi unit test stubs"""

    def setUp(self):
        self.api = api.service_domain_api.ServiceDomainApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_project_get_service_domains(self):
        """Test case for project_get_service_domains

        Get all service domains associated with a project by project ID.  # noqa: E501
        """
        pass

    def test_service_domain_create(self):
        """Test case for service_domain_create

        Create service domain.  # noqa: E501
        """
        pass

    def test_service_domain_delete(self):
        """Test case for service_domain_delete

        Delete a service domain as specified by its ID.  # noqa: E501
        """
        pass

    def test_service_domain_get(self):
        """Test case for service_domain_get

        Get a service domain by its ID.  # noqa: E501
        """
        pass

    def test_service_domain_get_effective_profile(self):
        """Test case for service_domain_get_effective_profile

        Get a service domain effective profile by ID.  # noqa: E501
        """
        pass

    def test_service_domain_get_nodes(self):
        """Test case for service_domain_get_nodes

        Retrieves all nodes for a service domain by service domain ID {svcDomainId}.  # noqa: E501
        """
        pass

    def test_service_domain_get_nodes_info(self):
        """Test case for service_domain_get_nodes_info

        Get nodes info for a service domain by service domain ID.  # noqa: E501
        """
        pass

    def test_service_domain_list(self):
        """Test case for service_domain_list

        Get service domains.  # noqa: E501
        """
        pass

    def test_service_domain_update(self):
        """Test case for service_domain_update

        Update a service domain by its ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
