# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.cloud_profile_api import CloudProfileApi  # noqa: E501
from kps_api.rest import ApiException


class TestCloudProfileApi(unittest.TestCase):
    """CloudProfileApi unit test stubs"""

    def setUp(self):
        self.api = api.cloud_profile_api.CloudProfileApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cloud_profile_create(self):
        """Test case for cloud_profile_create

        Create a cloud profile.  # noqa: E501
        """
        pass

    def test_cloud_profile_delete(self):
        """Test case for cloud_profile_delete

        Delete a cloud profile by its ID.  # noqa: E501
        """
        pass

    def test_cloud_profile_get(self):
        """Test case for cloud_profile_get

        Get a cloud profile according to profile ID.  # noqa: E501
        """
        pass

    def test_cloud_profile_list(self):
        """Test case for cloud_profile_list

        Get all cloud service profiles.  # noqa: E501
        """
        pass

    def test_cloud_profile_update(self):
        """Test case for cloud_profile_update

        Update a cloud profile by its ID.  # noqa: E501
        """
        pass

    def test_project_get_cloud_profiles(self):
        """Test case for project_get_cloud_profiles

        Get cloud profiles according to project ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
