# coding: utf-8

"""
    Nutanix Karbon Platform Services API reference.

    OpenAPI documentation for public facing Nutanix Karbon Platform Services API

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pathlib
from setuptools import setup, find_packages  # noqa: H301

NAME = "kps_api"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]
kps_api_packages = [
    "kps_api",
    "kps_api.api",
    "kps_api.models"
]

setup(
    name=NAME,
    version="1.3.10",
    description="Nutanix Karbon Platform Services Python SDK",
    author_email="karbon-platform-services-api@nutanix.com",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/nutanix/karbon-platform-services/tree/master/sdk/python",
    keywords=["Swagger", "Karbon Platform Services API reference."],
    install_requires=REQUIRES,
    packages=kps_api_packages,
    include_package_data=True
)
