# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class DockerProfile(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cloud_creds_id': 'str',
        'credentials': 'str',
        'description': 'str',
        'email': 'str',
        'id': 'str',
        'name': 'str',
        'pwd': 'str',
        'server': 'str',
        'type': 'str',
        'user_name': 'str'
    }

    attribute_map = {
        'cloud_creds_id': 'cloudCredsID',
        'credentials': 'credentials',
        'description': 'description',
        'email': 'email',
        'id': 'id',
        'name': 'name',
        'pwd': 'pwd',
        'server': 'server',
        'type': 'type',
        'user_name': 'userName'
    }

    def __init__(self, cloud_creds_id=None, credentials=None, description=None, email=None, id=None, name=None, pwd=None, server=None, type=None, user_name=None):  # noqa: E501
        """DockerProfile - a model defined in Swagger"""  # noqa: E501
        self._cloud_creds_id = None
        self._credentials = None
        self._description = None
        self._email = None
        self._id = None
        self._name = None
        self._pwd = None
        self._server = None
        self._type = None
        self._user_name = None
        self.discriminator = None
        if cloud_creds_id is not None:
            self.cloud_creds_id = cloud_creds_id
        if credentials is not None:
            self.credentials = credentials
        if description is not None:
            self.description = description
        if email is not None:
            self.email = email
        if id is not None:
            self.id = id
        self.name = name
        if pwd is not None:
            self.pwd = pwd
        self.server = server
        self.type = type
        if user_name is not None:
            self.user_name = user_name

    @property
    def cloud_creds_id(self):
        """Gets the cloud_creds_id of this DockerProfile.  # noqa: E501

        The CloudCreds to import Docker Profile from  # noqa: E501

        :return: The cloud_creds_id of this DockerProfile.  # noqa: E501
        :rtype: str
        """
        return self._cloud_creds_id

    @cloud_creds_id.setter
    def cloud_creds_id(self, cloud_creds_id):
        """Sets the cloud_creds_id of this DockerProfile.

        The CloudCreds to import Docker Profile from  # noqa: E501

        :param cloud_creds_id: The cloud_creds_id of this DockerProfile.  # noqa: E501
        :type: str
        """

        self._cloud_creds_id = cloud_creds_id

    @property
    def credentials(self):
        """Gets the credentials of this DockerProfile.  # noqa: E501

        The Credentials of the DockerProfile.  # noqa: E501

        :return: The credentials of this DockerProfile.  # noqa: E501
        :rtype: str
        """
        return self._credentials

    @credentials.setter
    def credentials(self, credentials):
        """Sets the credentials of this DockerProfile.

        The Credentials of the DockerProfile.  # noqa: E501

        :param credentials: The credentials of this DockerProfile.  # noqa: E501
        :type: str
        """

        self._credentials = credentials

    @property
    def description(self):
        """Gets the description of this DockerProfile.  # noqa: E501

        Description for the DockerProfile.  # noqa: E501

        :return: The description of this DockerProfile.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DockerProfile.

        Description for the DockerProfile.  # noqa: E501

        :param description: The description of this DockerProfile.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def email(self):
        """Gets the email of this DockerProfile.  # noqa: E501

        DockerProfile  email.  # noqa: E501

        :return: The email of this DockerProfile.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this DockerProfile.

        DockerProfile  email.  # noqa: E501

        :param email: The email of this DockerProfile.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def id(self):
        """Gets the id of this DockerProfile.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this DockerProfile.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DockerProfile.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this DockerProfile.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this DockerProfile.  # noqa: E501

        Name for the DockerProfile.  # noqa: E501

        :return: The name of this DockerProfile.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DockerProfile.

        Name for the DockerProfile.  # noqa: E501

        :param name: The name of this DockerProfile.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def pwd(self):
        """Gets the pwd of this DockerProfile.  # noqa: E501

        DockerProfile  Password.  # noqa: E501

        :return: The pwd of this DockerProfile.  # noqa: E501
        :rtype: str
        """
        return self._pwd

    @pwd.setter
    def pwd(self, pwd):
        """Sets the pwd of this DockerProfile.

        DockerProfile  Password.  # noqa: E501

        :param pwd: The pwd of this DockerProfile.  # noqa: E501
        :type: str
        """

        self._pwd = pwd

    @property
    def server(self):
        """Gets the server of this DockerProfile.  # noqa: E501

        DockerProfile  server.  # noqa: E501

        :return: The server of this DockerProfile.  # noqa: E501
        :rtype: str
        """
        return self._server

    @server.setter
    def server(self, server):
        """Sets the server of this DockerProfile.

        DockerProfile  server.  # noqa: E501

        :param server: The server of this DockerProfile.  # noqa: E501
        :type: str
        """
        if server is None:
            raise ValueError("Invalid value for `server`, must not be `None`")  # noqa: E501

        self._server = server

    @property
    def type(self):
        """Gets the type of this DockerProfile.  # noqa: E501

        DockerProfile  type.  # noqa: E501

        :return: The type of this DockerProfile.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DockerProfile.

        DockerProfile  type.  # noqa: E501

        :param type: The type of this DockerProfile.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["AWS", "GCP", "Azure", "ContainerRegistry"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def user_name(self):
        """Gets the user_name of this DockerProfile.  # noqa: E501

        DockerProfile  user.  # noqa: E501

        :return: The user_name of this DockerProfile.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this DockerProfile.

        DockerProfile  user.  # noqa: E501

        :param user_name: The user_name of this DockerProfile.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DockerProfile, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DockerProfile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
