# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.kiali_api import KialiApi  # noqa: E501
from kps_api.rest import ApiException


class TestKialiApi(unittest.TestCase):
    """KialiApi unit test stubs"""

    def setUp(self):
        self.api = api.kiali_api.KialiApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_app_dashboard(self):
        """Test case for app_dashboard

        """
        pass

    def test_app_details(self):
        """Test case for app_details

        """
        pass

    def test_app_health(self):
        """Test case for app_health

        """
        pass

    def test_app_list(self):
        """Test case for app_list

        """
        pass

    def test_app_metrics(self):
        """Test case for app_metrics

        """
        pass

    def test_error_traces(self):
        """Test case for error_traces

        """
        pass

    def test_get_config(self):
        """Test case for get_config

        """
        pass

    def test_get_status(self):
        """Test case for get_status

        """
        pass

    def test_graph_app(self):
        """Test case for graph_app

        """
        pass

    def test_graph_app_version(self):
        """Test case for graph_app_version

        """
        pass

    def test_graph_namespaces(self):
        """Test case for graph_namespaces

        The backing JSON for a namespaces graph.  # noqa: E501
        """
        pass

    def test_graph_service(self):
        """Test case for graph_service

        The backing JSON for a service node detail graph.  # noqa: E501
        """
        pass

    def test_graph_workload(self):
        """Test case for graph_workload

        The backing JSON for a workload node detail graph.  # noqa: E501
        """
        pass

    def test_istio_config_list(self):
        """Test case for istio_config_list

        """
        pass

    def test_istio_status(self):
        """Test case for istio_status

        """
        pass

    def test_namespace_health(self):
        """Test case for namespace_health

        """
        pass

    def test_namespace_list(self):
        """Test case for namespace_list

        """
        pass

    def test_namespace_metrics(self):
        """Test case for namespace_metrics

        """
        pass

    def test_namespace_tls(self):
        """Test case for namespace_tls

        """
        pass

    def test_namespace_validations(self):
        """Test case for namespace_validations

        """
        pass

    def test_pod_details(self):
        """Test case for pod_details

        """
        pass

    def test_pod_logs(self):
        """Test case for pod_logs

        """
        pass

    def test_root(self):
        """Test case for root

        """
        pass

    def test_service_dashboard(self):
        """Test case for service_dashboard

        """
        pass

    def test_service_details(self):
        """Test case for service_details

        """
        pass

    def test_service_health(self):
        """Test case for service_health

        """
        pass

    def test_service_list(self):
        """Test case for service_list

        """
        pass

    def test_service_metrics(self):
        """Test case for service_metrics

        """
        pass

    def test_spans_list(self):
        """Test case for spans_list

        """
        pass

    def test_traces_detail(self):
        """Test case for traces_detail

        """
        pass

    def test_workload_dashboard(self):
        """Test case for workload_dashboard

        """
        pass

    def test_workload_details(self):
        """Test case for workload_details

        """
        pass

    def test_workload_health(self):
        """Test case for workload_health

        """
        pass

    def test_workload_list(self):
        """Test case for workload_list

        """
        pass

    def test_workload_metrics(self):
        """Test case for workload_metrics

        """
        pass


if __name__ == '__main__':
    unittest.main()
