# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.node_api import NodeApi  # noqa: E501
from kps_api.rest import ApiException


class TestNodeApi(unittest.TestCase):
    """NodeApi unit test stubs"""

    def setUp(self):
        self.api = api.node_api.NodeApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_node_create(self):
        """Test case for node_create

        Create a node.  # noqa: E501
        """
        pass

    def test_node_delete(self):
        """Test case for node_delete

        Delete a node as specified by node ID.  # noqa: E501
        """
        pass

    def test_node_get(self):
        """Test case for node_get

        Get a node as specified by node ID.  # noqa: E501
        """
        pass

    def test_node_list(self):
        """Test case for node_list

        Get all service domain nodes.  # noqa: E501
        """
        pass

    def test_node_onboarded(self):
        """Test case for node_onboarded

        Update node post onboard info.  # noqa: E501
        """
        pass

    def test_node_update(self):
        """Test case for node_update

        Update a node as specified by node ID.  # noqa: E501
        """
        pass

    def test_project_get_nodes(self):
        """Test case for project_get_nodes

        Get all service domain nodes associated with a project by project ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
