# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.user_api import UserApi  # noqa: E501
from kps_api.rest import ApiException


class TestUserApi(unittest.TestCase):
    """UserApi unit test stubs"""

    def setUp(self):
        self.api = api.user_api.UserApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_is_email_available(self):
        """Test case for is_email_available

        Check if the given email is available for create user.  # noqa: E501
        """
        pass

    def test_project_get_users_v2(self):
        """Test case for project_get_users_v2

        Get project users.  # noqa: E501
        """
        pass

    def test_user_create_v2(self):
        """Test case for user_create_v2

        Create user.  # noqa: E501
        """
        pass

    def test_user_delete_v2(self):
        """Test case for user_delete_v2

        Delete user by ID.  # noqa: E501
        """
        pass

    def test_user_get_v2(self):
        """Test case for user_get_v2

        Get user by ID.  # noqa: E501
        """
        pass

    def test_user_list_v2(self):
        """Test case for user_list_v2

        Get users.  # noqa: E501
        """
        pass

    def test_user_update_v3(self):
        """Test case for user_update_v3

        Update user with a given ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
